@@ -11,7 +11,7 @@ def test_keep():
     nb.cells.append(new_code_cell(valid_data, metadata={"tags": [keep_tag]}))
     nb.cells.append(new_code_cell("# not this one", metadata={"tags": ["empty"]}))
 
-    nb, _ = TagsKeepPreproccesor(tags={keep_tag}).preprocess(nb, None)
+    nb, _ = TagsKeepPreproccesor(tags=[keep_tag]).preprocess(nb, None)
     assert len(nb.cells) == 1
     assert nb.cells[0]["source"] == valid_data
 
@@ -23,6 +23,6 @@ def test_keep2():
     nb.cells.append(new_code_cell(valid_data, metadata={"tags": [keep_tag]}))
     nb.cells.append(new_code_cell("# not this one either"))
 
-    nb, _ = TagsKeepPreproccesor(tags={keep_tag}).preprocess(nb, None)
+    nb, _ = TagsKeepPreproccesor(tags=[keep_tag]).preprocess(nb, None)
     assert nb.cells[0]["source"] == valid_data
     assert len(nb.cells) == 1
